window.Gleam.initSearch([{"doc":"fswalk","title":"fswalk","content":"# fswalk\n\nRecursively walk the filesystem starting from the provided path.\n\n[![Package Version](https://img.shields.io/hexpm/v/fswalk)](https://hex.pm/packages/fswalk)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/fswalk/)\n\n```sh\ngleam add fswalk\n```\n\n```gleam\nimport fswalk\n\npub fn main() {\n  fswalk.builder()\n  |&gt; fswalk.with_path(&quot;test/fixture&quot;)\n  |&gt; fswalk.with_traversal_filter(fn(entry) {\n    !string.contains(does: entry.filename, contain: &quot;ignore_folder&quot;)\n  })\n  |&gt; fswalk.walk\n  |&gt; iterator.fold([], fn(acc, it) {\n    case it {\n      Ok(entry) if !entry.stat.is_directory -&gt; [entry.filename, ..acc]\n      _ -&gt; acc\n    }\n  })\n  |&gt; should.equal([&quot;test/fixture/b/c/d&quot;, &quot;test/fixture/a&quot;])\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/fswalk&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n\n## changelog\n\n- 1.0.0 - init\n- 2.0.0 - support traverse filtering in tandem with entry filtering\n- 3.0.0\n  - dropped `.with_entry_filter`. Use `iterator.*` functions on the output instead.\n  - dropped sugar functions `.map/.each/.fold`. Use `iterator.*` functions on the output instead.\n","url":"index.html"},{"doc":"fswalk","title":"Entry","content":"pub type Entry {\n  Entry(filename: String, stat: Stat)\n}\n Data about the file/folder walked.\nEntry(filename: String, stat: Stat)\n\n\nSynonyms:\nfswalk.Entry\nfswalk Entry","url":"fswalk.html#Entry"},{"doc":"fswalk","title":"EntryFilter","content":"pub type EntryFilter =\n  fn(Entry) -&gt; Bool\n A function that filters entries in the walk iterator.\n\nSynonyms:\nfswalk.EntryFilter\nfswalk EntryFilter","url":"fswalk.html#EntryFilter"},{"doc":"fswalk","title":"Stat","content":"pub type Stat {\n  Stat(is_directory: Bool)\n}\n Incomplete [stat](https://www.man7.org/linux/man-pages/man2/stat.2.html) data.\n\nStat(is_directory: Bool)\n\n\nSynonyms:\nfswalk.Stat\nfswalk Stat","url":"fswalk.html#Stat"},{"doc":"fswalk","title":"WalkBuilder","content":"pub opaque type WalkBuilder(traversal_filter, path)\n See [builder](#builder).\n\n\nSynonyms:\nfswalk.WalkBuilder\nfswalk WalkBuilder","url":"fswalk.html#WalkBuilder"},{"doc":"fswalk","title":"builder","content":"pub fn builder() -&gt; WalkBuilder(Non, Non)\n Create a new WalkBuilder\n\nSynonyms:\nfswalk.builder\nfswalk builder","url":"fswalk.html#builder"},{"doc":"fswalk","title":"walk","content":"pub fn walk(\n  builder: WalkBuilder(a, Som),\n) -&gt; Iterator(Result(Entry, FileError))\n Walks the filesystem lazily.\n\nSynonyms:\nfswalk.walk\nfswalk walk","url":"fswalk.html#walk"},{"doc":"fswalk","title":"with_path","content":"pub fn with_path(\n  builder: WalkBuilder(a, b),\n  path: String,\n) -&gt; WalkBuilder(a, Som)\n Create a new WalkBuilder bound to a directory path to walk\n\nSynonyms:\nfswalk.with_path\nfswalk with_path","url":"fswalk.html#with_path"},{"doc":"fswalk","title":"with_traversal_filter","content":"pub fn with_traversal_filter(\n  builder: WalkBuilder(a, b),\n  traversal_filter: fn(Entry) -&gt; Bool,\n) -&gt; WalkBuilder(Som, b)\n Create a new WalkBuilder adding an additional entry filter function.\n\nSynonyms:\nfswalk.with_traversal_filter\nfswalk with_traversal_filter","url":"fswalk.html#with_traversal_filter"},{"doc":"fswalk","title":"fswalk","content":"","url":"fswalk.html"}]);